@@ -17,5 +17,11 @@ class Command(BaseCommand):
         conf = json.dumps(JS_CONFIG)
         current_env = os.environ.copy()
         current_env['REACT_BRIDGE_JS_CONFIG'] = conf
-        run_npm_command(['install'], cwd=BUNDLER_DIR)
-        run_npm_command(['build'], env=current_env, cwd=BUNDLER_DIR)
\ No newline at end of file
+        current_env['NODE_ENV'] = 'production'
+        run_npm_command(['install'], cwd=JS_CONFIG['package_json_path'])
+        prod_config_file = os.path.join(BUNDLER_DIR, 'webpack.prod.js')
+        run_npm_command(
+            ['run', 'webpack', '-p', '--config', prod_config_file],
+            env=current_env,
+            cwd=JS_CONFIG['package_json_path']
+        )
\ No newline at end of file
